/******************************************************************************
*                                                                             *
*                                 Copyright by                                *
*                                                                             *
*                               Azoteq (Pty) Ltd                              *
*                           Republic of South Africa                          *
*                                                                             *
*                            Tel: +27(0)21 863 0033                           *
*                                 www.azoteq.com                              *
*                                                                             *
*******************************************************************************
* Refer to IQS9150 datasheet for more information, available here:             *
* - https://www.azoteq.com/design/datasheets/                                 *
*******************************************************************************
*                       IQS9150 - Registers & Memory Map                       *
*******************************************************************************/

#ifndef __IQS9150_ADDRESSES_H
#define __IQS9150_ADDRESSES_H

#include "../IQS9150.h"

/* Version Information - Read Only */
/* Memory Map Position 0x1000 - 0x1013 */
#define IQS9150_MM_PROD_NUM                         0x1000
#define IQS9150_MM_MAJOR_VERSION_NUM                0x1002
#define IQS9150_MM_MINOR_VERSION_NUM                0x1004
#define IQS9150_MM_PROD_SHA                         0x1006
#define IQS9150_MM_LIB_NUM                          0x100A
#define IQS9150_MM_LIB_MAJOR_VERSION_NUM            0x100C
#define IQS9150_MM_LIB_MINOR_VERSION_NUM            0x100E
#define IQS9150_MM_LIB_SHA                          0x1010

/* Device Data - Read Only */
/* Memory Map Position 0x1014 - 0x105B */
#define IQS9150_MM_RELATIVE_X                       0x1014
#define IQS9150_MM_RELATIVE_Y                       0x1016
#define IQS9150_MM_GESTURE_X                        0x1018
#define IQS9150_MM_GESTURE_Y                        0x101A
#define IQS9150_MM_SINGLE_FINGER_GESTURES           0x101C
#define IQS9150_MM_DOUBLE_FINGER_GESTURES           0x101E
#define IQS9150_MM_INFO_FLAGS                       0x1020
#define IQS9150_MM_TRACKPAD_FLAGS                   0x1022
#define IQS9150_MM_FINGER_1_X                       0x1024
#define IQS9150_MM_FINGER_1_Y                       0x1026
#define IQS9150_MM_FINGER_1_TOUCH_STRENGTH          0x1028
#define IQS9150_MM_FINGER_1_AREA                    0x102A
#define IQS9150_MM_FINGER_2_X                       0x102C
#define IQS9150_MM_FINGER_2_Y                       0x102E
#define IQS9150_MM_FINGER_2_TOUCH_STRENGTH          0x1030
#define IQS9150_MM_FINGER_2_AREA                    0x1032
#define IQS9150_MM_FINGER_3_X                       0x1034
#define IQS9150_MM_FINGER_3_Y                       0x1036
#define IQS9150_MM_FINGER_3_TOUCH_STRENGTH          0x1038
#define IQS9150_MM_FINGER_3_AREA                    0x103A
#define IQS9150_MM_FINGER_4_X                       0x103C
#define IQS9150_MM_FINGER_4_Y                       0x103E
#define IQS9150_MM_FINGER_4_TOUCH_STRENGTH          0x1040
#define IQS9150_MM_FINGER_4_AREA                    0x1042
#define IQS9150_MM_FINGER_5_X                       0x1044
#define IQS9150_MM_FINGER_5_Y                       0x1046
#define IQS9150_MM_FINGER_5_TOUCH_STRENGTH          0x1048
#define IQS9150_MM_FINGER_5_AREA                    0x104A
#define IQS9150_MM_FINGER_6_X                       0x104C
#define IQS9150_MM_FINGER_6_Y                       0x104E
#define IQS9150_MM_FINGER_6_TOUCH_STRENGTH          0x1050
#define IQS9150_MM_FINGER_6_AREA                    0x1052
#define IQS9150_MM_FINGER_7_X                       0x1054
#define IQS9150_MM_FINGER_7_Y                       0x1056
#define IQS9150_MM_FINGER_7_TOUCH_STRENGTH          0x1058
#define IQS9150_MM_FINGER_7_AREA                    0x105A

#define IQS9150_MM_SYSTEM_CONTROL                   0x11BC
#define IQS9150_MM_CONFIG_SETTINGS                  0x11BE
#define IQS9150_MM_ALP_COMPENSATION_RX0_0           0x115C
#define IQS9150_MM_I2C_KEY                          0x1176
#define IQS9150_MM_MINOR_VERSION                    0x1178
#define IQS9150_MM_TP_ATI_MULTDIV_L                 0x117A
#define IQS9150_MM_TP_ATI_TARGET_0                  0x1196
#define IQS9150_MM_ACTIVE_MODE_SAMPLING_PERIOD_0    0x11A2
#define IQS9150_MM_SYSTEM_CONTROL_0                 0x11BC
#define IQS9150_MM_ALP_SETUP_0                      0x11C2
#define IQS9150_MM_TRACKPAD_TOUCH_SET_THRESHOLD     0x11CC
#define IQS9150_MM_ALP_COUNT_BETA_LP1               0x11D4
#define IQS9150_MM_TP_FRAC                          0x11D8
#define IQS9150_MM_TRACKPAD_SETTINGS_0_0            0x11E2
#define IQS9150_MM_GESTURE_ENABLE_0                 0x11F6
#define IQS9150_MM_RX_TX_MAP_0                      0x1218
#define IQS9150_MM_TP_DISABLE_TX0_0                 0x1246
#define IQS9150_MM_TP_DISABLE_TX11_0                0x1272
#define IQS9150_MM_SNAP_ENABLE_TX0_0                0x129E
#define IQS9150_MM_SNAP_ENABLE_TX11_0               0x12CA
#define IQS9150_MM_TT_ADJUST_CH0                    0x12F6
#define IQS9150_MM_NUMBER_OF_VIRTUAL_SENSORS_0      0x14F0
#define IQS9150_MM_B4_TOP_LEFT_X_0                  0x1512
#define IQS9150_MM_B10_TOP_LEFT_X_0                 0x1542
#define IQS9150_MM_SLIDER_DEADZONE_0                0x1572
#define IQS9150_MM_S5_TOP_LEFT_X_0                  0x15A6
#define IQS9150_MM_W0_CENTRE_X_0                    0x15C4

#endif /* __IQS9150_ADDRESSES_H */
